==> pkgdepends_0.6.0.tar.gz: pkgdepends/tests/testthat/_snaps/new-r/type-bioc.md <==
# resolve_remote

    Code
      as.list(res)
    Output
      $package
      [1] "Biobase"
      
      $version
      [1] "1.2.3"
      
      $md5sum
      [1] "<md5sum>"
      
      $needscompilation
      [1] FALSE
      
      $repodir
      [1] "src/contrib"
      
      $rversion
      [1] "*"
      
      $platform
      [1] "source"
      
      $priority
      [1] NA
      
      $ref
      [1] "bioc::Biobase"
      
      $type
      [1] "bioc"
      
      $status
      [1] "OK"
      
      $target
      [1] "src/contrib/Biobase_1.2.3.tar.gz"
      
      $mirror
      [1] "http://127.0.0.1:<port>//packages/<bioc-version>/bioc"
      
      $sources
      $sources[[1]]
      [1] "http://127.0.0.1:<port>//packages/<bioc-version>/bioc/src/contrib/Biobase_1.2.3.tar.gz"
      
      
      $filesize
      [1] NA
      
      $sha256
      [1] NA
      
      $sysreqs
      [1] NA
      
      $deps
      $deps[[1]]
      # A data frame: 9 x 5
        ref          type     package      op    version 
      * <chr>        <chr>    <chr>        <chr> <chr>   
      1 R            depends  R            ">="  "2.10"  
      2 BiocGenerics depends  BiocGenerics ">="  "0.27.1"
      3 utils        depends  utils        ""    ""      
      4 methods      imports  methods      ""    ""      
      5 tools        suggests tools        ""    ""      
      6 tkWidgets    suggests tkWidgets    ""    ""      
      7 ALL          suggests ALL          ""    ""      
      8 RUnit        suggests RUnit        ""    ""      
      9 golubEsets   suggests golubEsets   ""    ""      
      
      
      $built
      [1] NA
      
      $repotype
      [1] "bioc"
      
      $direct
      [1] TRUE
      
      $params
      $params[[1]]
      character(0)
      
      
      $metadata
      $metadata[[1]]
                                        RemoteType 
                                            "bioc" 
                                      RemotePkgRef 
                                   "bioc::Biobase" 
                                         RemoteRef 
                                   "bioc::Biobase" 
                                       RemoteRepos 
      "http://127.0.0.1:<port>//packages/<bioc-version>/bioc" 
                                 RemotePkgPlatform 
                                          "source" 
                                         RemoteSha 
                                           "1.2.3"

==> pkgdepends_0.9.0.tar.gz: pkgdepends/tests/testthat/_snaps/new-r/type-bioc.md <==
# resolve_remote

    Code
      as.list(res)
    Output
      $package
      [1] "Biobase"
      
      $version
      [1] "1.2.3"
      
      $md5sum
      [1] "<md5sum>"
      
      $needscompilation
      [1] FALSE
      
      $repodir
      [1] "src/contrib"
      
      $rversion
      [1] "*"
      
      $platform
      [1] "source"
      
      $priority
      [1] NA
      
      $ref
      [1] "bioc::Biobase"
      
      $type
      [1] "bioc"
      
      $status
      [1] "OK"
      
      $target
      [1] "src/contrib/Biobase_1.2.3.tar.gz"
      
      $mirror
      [1] "http://127.0.0.1:<port>//packages/<bioc-version>/bioc"
      
      $sources
      $sources[[1]]
      [1] "http://127.0.0.1:<port>//packages/<bioc-version>/bioc/src/contrib/Biobase_1.2.3.tar.gz"
      
      
      $filesize
      [1] NA
      
      $sha256
      [1] NA
      
      $sysreqs
      [1] NA
      
      $deps
      $deps[[1]]
      # A data frame: 9 x 5
        ref          type     package      op    version 
        <chr>        <chr>    <chr>        <chr> <chr>   
      1 ALL          suggests ALL          ""    ""      
      2 BiocGenerics depends  BiocGenerics ">="  "0.27.1"
      3 R            depends  R            ">="  "2.10"  
      4 RUnit        suggests RUnit        ""    ""      
      5 golubEsets   suggests golubEsets   ""    ""      
      6 methods      imports  methods      ""    ""      
      7 tkWidgets    suggests tkWidgets    ""    ""      
      8 tools        suggests tools        ""    ""      
      9 utils        depends  utils        ""    ""      
      
      
      $built
      [1] NA
      
      $repotype
      [1] "bioc"
      
      $direct
      [1] TRUE
      
      $params
      $params[[1]]
      character(0)
      
      
      $metadata
      $metadata[[1]]
                                        RemoteType 
                                            "bioc" 
                                      RemotePkgRef 
                                   "bioc::Biobase" 
                                         RemoteRef 
                                   "bioc::Biobase" 
                                       RemoteRepos 
      "http://127.0.0.1:<port>//packages/<bioc-version>/bioc" 
                                 RemotePkgPlatform 
                                          "source" 
                                         RemoteSha 
                                           "1.2.3"
